% =========================================================================
% Publication Motion Blur Test
% =========================================================================
% M.Erdem Isenkul
% =========================================================================
% Purpose:
% =========================================================================     

%--- Reset Workspace and Command Line
clc
clear
close all

%--- Import Library, Data and Functions
format shortg
addpath(genpath('libL4'))   %>> L4 DB,Connections
addpath(genpath('libfunc')) %>> Custom Functions
addpath(genpath('results')) %>> Figures,Tables and etc..
addpath(genpath('libsvm'))  %>> libSVM path

%--- Load L4 Settings
NL4=182;                                %>> # of L4 feature
theta = 0.65;	Nrevs = 20;	lambda = 1; %>> Connection Settings
image_load;
load WTH_T65_L1;    load WLAT_T65_L1;   %>> WTH Connection

%--- Load Test Settings and Samples
IRS = 77777;    rand ('state', IRS); %>> Random Seed

Ntrials=2000;   %>> # of Samples
shift=10;       %>> Length of Motion (Pixels)
hangle=0;       %>> First Motion Direction (Degree)
vangle=90;      %>> Second Motion Direction (Degree)
create_win_v1_s_only;

%% --- Figure 10: For best sigma value, determination of Shift vs Linear Classification Accuracy --- %%
disp('Figure 10: Testing');
%--- Settings
shift_limit=10;         %>> Shift Limit for Loop

accuracy_motion_fths=[];
accuracy_motion_fl4s=[];

for shift=1:shift_limit
    
    clc
    rand ('state', IRS);
    create_win_motion;  %>> Create Samples
    
    %========~~~Thalamic Representation Test~~~===========================%
    disp('FTHS')
    %--- Classification
    traind  =   [FTHS_v2_h FTHS_v2_v]';
    testd   =   [FTHS_v3_h FTHS_v3_v]';
    
    class_size=size(traind,1)/2;
    classes=[zeros(class_size,1);ones(class_size,1)];
 
    %----- Linear SVM Settings
    custom_nu=0.9;
    val=strcat('-s 1 -h 0 -t 0 -n ',{' '},num2str(custom_nu));
    model=svmtrain(classes,traind,val{:});
    [pred_class, accuracy, prob_estimates] = svmpredict(classes, testd, model, '-b 0');
    accuracy_motion_fths(shift,1)=mean(pred_class==classes);
  
    %============~~~FL4S Representation Test~~~===========================%
    disp('FL4S')
     %--- Classification
    traind  =   [FL4S_v2_h FL4S_v2_v]';
    testd   =   [FL4S_v3_h FL4S_v3_v]';
    
    class_size=size(traind,1)/2;
    classes=[zeros(class_size,1);ones(class_size,1)];
       
    %----- Linear SVM Settings
    custom_nu=0.9;
    val=strcat('-s 1 -h 0 -t 0 -n ',{' '},num2str(custom_nu));
    model=svmtrain(classes,traind,val{:});
    [pred_class, accuracy, prob_estimates] = svmpredict(classes, testd, model, '-b 0');
    accuracy_motion_fl4s(shift,1)=mean(pred_class==classes);
    
end
%
%%
%--- Plot Figure-10 Shift vs Accuracy Linear Classification
plot(1:shift_limit,accuracy_motion_fths(1:shift_limit,1)*100,'-b*');
hold on
plot(1:shift_limit,accuracy_motion_fl4s(1:shift_limit,1)*100,'-r*');
set(gca,'xlim',[1 10],'ylim',[30 100]);
legend('Thalamic','Layer-4','Location','northoutside','Orientation','vertical');
xlabel('Motion Size (pixels)');
ylabel('SVM Linear Kernel Accuracy(%)')